@@ -24,8 +24,6 @@ the numbers, and attempts to give them meaningful names.
 
 import sys
 
-from nuitka.Options import isFullCompat
-
 
 def _getPythonVersion():
     big, major, minor = sys.version_info[0:3]
@@ -42,10 +40,6 @@ def isAtLeastSubVersion(version):
 
 
 def doShowUnknownEncodingName():
-    # It's best to do it.
-    if not isFullCompat():
-        return True
-
     # Python 3.3.3 or higher does it, 3.4 always did.
     if python_version >= 333:
         return True
@@ -59,3 +53,22 @@ def doShowUnknownEncodingName():
         return True
 
     return False
+
+
+def getErrorMessageExecWithNestedFunction():
+    """ Error message of the concrete Python in case an exec occurs in a
+        function that takes a closure variable.
+    """
+
+    assert python_version < 300
+
+    # Need to use exec to detect the syntax error, pylint: disable=W0122
+
+    try:
+        exec("""
+def f():
+   exec ""
+   def nested():
+      return closure""")
+    except SyntaxError as e:
+        return e.message.replace("'f'", "'%s'")
