@@ -85,11 +85,12 @@ def formatOutput(e):
 
 def raiseSyntaxError(reason, source_ref, col_offset = None, display_file = True,
                      display_line = True, source_line = None):
-    # TODO: This could could "linecache" module maybe.
     def readSource():
-        source = open(source_ref.getFilename(), 'rU').readlines()
-
-        return source[source_ref.getLineNumber() - 1]
+        import linecache
+        return linecache.getline(
+            filename = source_ref.getFilename(),
+            lineno   = source_ref.getLineNumber()
+        )
 
     if display_file and display_line:
         if source_line is None:
