@@ -25,10 +25,16 @@ def getLineNumberUpdateCode(context):
     if frame_handle is None:
         return ""
     else:
-        return "%s->f_lineno = %s;" % (
-            frame_handle,
-            context.getCurrentSourceCodeReference().getLineNumber()
-        )
+        source_ref = context.getCurrentSourceCodeReference()
+
+        if source_ref.shallSetCurrentLine():
+            return "%s->f_lineno = %d;" % (
+                frame_handle,
+                source_ref.getLineNumber()
+            )
+        else:
+            return ""
+
 
 def emitLineNumberUpdateCode(context, emit):
     code = getLineNumberUpdateCode(context)
@@ -36,6 +42,7 @@ def emitLineNumberUpdateCode(context, emit):
     if code:
         emit(code)
 
+
 def getSetLineNumberCodeRaw(to_name, emit, context):
     assert context.getFrameHandle() is not None
 
@@ -47,14 +54,6 @@ def getSetLineNumberCodeRaw(to_name, emit, context):
     )
 
 
-# TODO: The below should probably become unused.
-def getSetLineNumberCode(source_ref, emit, context):
-    if source_ref.shallSetCurrentLine():
-        line_number = source_ref.getLineNumber()
-
-        getSetLineNumberCodeRaw(line_number, emit, context)
-
-
 def getLineNumberCode(to_name, emit, context):
     assert context.getFrameHandle() is not None
 
