@@ -44,6 +44,9 @@ global_copyright = """\
 template_metapath_loader_compiled_module_entry = """\
 { (char *)"%(module_name)s", MOD_INIT_NAME( %(module_identifier)s ), NUITKA_COMPILED_MODULE },"""
 
+template_metapath_loader_compiled_package_entry = """\
+{ (char *)"%(module_name)s", MOD_INIT_NAME( %(module_identifier)s ), NUITKA_COMPILED_PACKAGE },"""
+
 template_metapath_loader_shlib_module_entry = """\
 { (char *)"%(module_name)s", NULL, NUITKA_SHLIB_MODULE },"""
 
@@ -53,6 +56,11 @@ main_program = """\
 // calls the initialization code of the __main__ module.
 
 #include "structseq.h"
+
+#if %(python_no_warnings)d
+extern PyObject *const_str_plain_ignore;
+#endif
+
 #ifdef _NUITKA_WINMAIN_ENTRY_POINT
 int __stdcall WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance, char* lpCmdLine, int nCmdShow )
 {
@@ -167,10 +175,36 @@ int main( int argc, char *argv[] )
     setEarlyFrozenModulesFileAttribute();
 #endif
 
+    // Disable Python warnings if requested to.
+#if %(python_no_warnings)d
+    // Should be same as:
+    //   warnings.simplefilter("ignore", UserWarning)
+    //   warnings.simplefilter("ignore", DeprecationWarning)
+    // There is no C-API to control warnings. We don't care if it actually
+    // works, i.e. return code of "simplefilter" function is not checked.
+    {
+        PyObject *warnings = PyImport_ImportModule( "warnings" );
+        if ( warnings != NULL )
+        {
+            PyObject *simplefilter = PyObject_GetAttrString( warnings, "simplefilter" );
+
+            if ( simplefilter != NULL )
+            {
+                PyObject *result1 = PyObject_CallFunctionObjArgs( simplefilter, const_str_plain_ignore, PyExc_UserWarning, NULL );
+                assert( result1 );
+                Py_XDECREF( result1 );
+                PyObject *result2 = PyObject_CallFunctionObjArgs( simplefilter, const_str_plain_ignore, PyExc_DeprecationWarning, NULL );
+                assert( result2 );
+                Py_XDECREF( result2 );
+            }
+        }
+    }
+#endif
+
     // Execute the "__main__" module init function.
     MOD_INIT_NAME( __main__ )();
 
-    if ( ERROR_OCCURED() )
+    if ( ERROR_OCCURRED() )
     {
         // Cleanup code may need a frame, so put one back.
         PyThreadState_GET()->frame = MAKE_FRAME( %(code_identifier)s, module___main__ );
@@ -182,6 +216,11 @@ int main( int argc, char *argv[] )
     {
         Py_Exit( 0 );
     }
+
+    // Dead code, just for the compiler to be happy. The above branches both
+    // do Py_Exit() which is not supposed to return.
+    assert(false);
+    return 0;
 }
 """
 
