@@ -22,15 +22,19 @@ statement, 'if a: ... else: ...' and there is no 'elif', because that is
 expressed via nesting of conditional statements.
 """
 
-from .NodeBases import ExpressionChildrenHavingBase, StatementChildrenHavingBase
+from nuitka.nodes.BuiltinTypeNodes import ExpressionBuiltinBool
 
-# Delayed import into multiple branches is not an issue, pylint: disable=W0404
+from .NodeBases import ExpressionChildrenHavingBase, StatementChildrenHavingBase
 
 
 class ExpressionConditional(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_CONDITIONAL"
 
-    named_children = ( "condition", "expression_yes", "expression_no" )
+    named_children = (
+        "condition",
+        "expression_yes",
+        "expression_no"
+    )
 
     def __init__(self, condition, yes_expression, no_expression, source_ref):
         ExpressionChildrenHavingBase.__init__(
@@ -55,13 +59,12 @@ class ExpressionConditional(ExpressionChildrenHavingBase):
     getExpressionNo = ExpressionChildrenHavingBase.childGetter(
         "expression_no"
     )
+
     getCondition = ExpressionChildrenHavingBase.childGetter(
         "condition"
     )
 
     def computeExpressionRaw(self, constraint_collection):
-        # Children can tell all we need to know, pylint: disable=W0613
-
         # Query the truth value after the expression is evaluated, once it is
         # evaluated in onExpression, it is known.
         constraint_collection.onExpression(
@@ -73,11 +76,11 @@ class ExpressionConditional(ExpressionChildrenHavingBase):
         # not matter at all.
         if condition.willRaiseException(BaseException):
             return condition, "new_raise", """\
-Conditional statements already raises implicitely in condition, removing \
+Conditional statements already raises implicitly in condition, removing \
 branches."""
 
-
-        # If the condition raises, we let that escape.
+        # If the condition raises, we let that escape instead, and the
+        # branches don't matter at all.
         if condition.willRaiseException(BaseException):
             return condition, "new_raise", """\
 Conditional expression raises in condition."""
@@ -159,9 +162,7 @@ Conditional expression raises in condition."""
             return self, None, None
 
     def mayHaveSideEffectsBool(self):
-        condition = self.getCondition()
-
-        if condition.mayHaveSideEffectsBool():
+        if self.getCondition().mayHaveSideEffectsBool():
             return True
 
         if self.getExpressionYes().mayHaveSideEffectsBool():
@@ -172,15 +173,52 @@ Conditional expression raises in condition."""
 
         return False
 
-    def mayProvideReference(self):
-        return self.getExpressionYes().mayProvideReference() or \
-               self.getExpressionNo().mayProvideReference()
+    def mayRaiseException(self, exception_type):
+        condition = self.getCondition()
+
+        if condition.mayRaiseException(exception_type):
+            return True
+
+        if condition.mayRaiseExceptionBool(exception_type):
+            return True
+
+        yes_branch = self.getExpressionYes()
+
+        # Handle branches that became empty behind our back
+        if yes_branch is not None and \
+           yes_branch.mayRaiseException(exception_type):
+            return True
+
+        no_branch = self.getExpressionNo()
+
+        # Handle branches that became empty behind our back
+        if no_branch is not None and \
+           no_branch.mayRaiseException(exception_type):
+            return True
+
+        return False
+
+    def mayRaiseExceptionBool(self, exception_type):
+        if self.getCondition().mayRaiseExceptionBool():
+            return True
+
+        if self.getExpressionYes().mayRaiseExceptionBool():
+            return True
+
+        if self.getExpressionNo().mayRaiseExceptionBool():
+            return True
+
+        return False
 
 
 class StatementConditional(StatementChildrenHavingBase):
     kind = "STATEMENT_CONDITIONAL"
 
-    named_children = ( "condition", "yes_branch", "no_branch" )
+    named_children = (
+        "condition",
+        "yes_branch",
+        "no_branch"
+    )
 
     def __init__(self, condition, yes_branch, no_branch, source_ref):
         StatementChildrenHavingBase.__init__(
@@ -193,11 +231,11 @@ class StatementConditional(StatementChildrenHavingBase):
             source_ref = source_ref
         )
 
-    getCondition = StatementChildrenHavingBase.childGetter( "condition" )
-    getBranchYes = StatementChildrenHavingBase.childGetter( "yes_branch" )
-    setBranchYes = StatementChildrenHavingBase.childSetter( "yes_branch" )
-    getBranchNo = StatementChildrenHavingBase.childGetter( "no_branch" )
-    setBranchNo = StatementChildrenHavingBase.childSetter( "no_branch" )
+    getCondition = StatementChildrenHavingBase.childGetter("condition")
+    getBranchYes = StatementChildrenHavingBase.childGetter("yes_branch")
+    setBranchYes = StatementChildrenHavingBase.childSetter("yes_branch")
+    getBranchNo = StatementChildrenHavingBase.childGetter("no_branch")
+    setBranchNo = StatementChildrenHavingBase.childSetter("no_branch")
 
     def isStatementAborting(self):
         yes_branch = self.getBranchYes()
@@ -215,6 +253,55 @@ class StatementConditional(StatementChildrenHavingBase):
         else:
             return False
 
+    def mayRaiseException(self, exception_type):
+        condition = self.getCondition()
+
+        if condition.mayRaiseException(exception_type):
+            return True
+
+        if condition.mayRaiseExceptionBool(exception_type):
+            return True
+
+        yes_branch = self.getBranchYes()
+
+        # Handle branches that became empty behind our back
+        if yes_branch is not None and \
+           yes_branch.mayRaiseException(exception_type):
+            return True
+
+        no_branch = self.getBranchNo()
+
+        # Handle branches that became empty behind our back
+        if no_branch is not None and \
+           no_branch.mayRaiseException(exception_type):
+            return True
+
+        return False
+
+    def needsFrame(self):
+        condition = self.getCondition()
+
+        if condition.mayRaiseException(BaseException):
+            return True
+
+        if condition.mayRaiseExceptionBool(BaseException):
+            return True
+
+        yes_branch = self.getBranchYes()
+
+        # Handle branches that became empty behind our back
+        if yes_branch is not None and \
+           yes_branch.needsFrame():
+            return True
+
+        no_branch = self.getBranchNo()
+
+        # Handle branches that became empty behind our back
+        if no_branch is not None and \
+           no_branch.needsFrame():
+            return True
+
+        return False
 
     def computeStatement(self, constraint_collection):
         # This is rather complex stuff, pylint: disable=R0912
@@ -237,7 +324,7 @@ class StatementConditional(StatementChildrenHavingBase):
             )
 
             return result, "new_raise", """\
-Conditional statements already raises implicitely in condition, removing \
+Conditional statements already raises implicitly in condition, removing \
 branches."""
 
         from nuitka.optimizations.ConstraintCollections import \
@@ -248,10 +335,10 @@ branches."""
         truth_value = condition.getTruthValue()
 
         # TODO: We now know that condition evaluates to true for the yes branch
-        # and to not true for no branch, the branch should know that.
+        # and to not true for no branch, the branch collection should know that.
         yes_branch = self.getBranchYes()
 
-        # Handle branches that became empty behind our back
+        # Handle branches that became empty behind our back.
         if yes_branch is not None:
             if not yes_branch.getStatements():
                 yes_branch = None
@@ -307,6 +394,12 @@ branches."""
             from .NodeMakingHelpers import \
                 makeStatementExpressionOnlyReplacementNode
 
+            if truth_value is None:
+                condition = ExpressionBuiltinBool(
+                    value      = condition,
+                    source_ref = condition.getSourceReference()
+                )
+
             # With both branches eliminated, the condition remains as a side
             # effect.
             result = makeStatementExpressionOnlyReplacementNode(
@@ -325,7 +418,7 @@ Both branches have no effect, reduced to evaluate condition."""
             from .OperatorNodes import ExpressionOperationNOT
 
             new_statement = StatementConditional(
-                condition = ExpressionOperationNOT(
+                condition  = ExpressionOperationNOT(
                     operand    = condition,
                     source_ref = condition.getSourceReference()
                 ),
@@ -363,3 +456,43 @@ Empty 'yes' branch for condition was replaced with inverted condition check."""
 Condition for branch was predicted to be always %s.""" % choice
 
         return self, None, None
+
+    def mayReturn(self):
+        yes_branch = self.getBranchYes()
+
+        if yes_branch is not None and yes_branch.mayReturn():
+            return True
+
+        no_branch = self.getBranchNo()
+
+        if no_branch is not None and no_branch.mayReturn():
+            return True
+
+        return False
+
+    def mayBreak(self):
+        yes_branch = self.getBranchYes()
+
+        if yes_branch is not None and yes_branch.mayBreak():
+            return True
+
+        no_branch = self.getBranchNo()
+
+        if no_branch is not None and no_branch.mayBreak():
+            return True
+
+        return False
+
+
+    def mayContinue(self):
+        yes_branch = self.getBranchYes()
+
+        if yes_branch is not None and yes_branch.mayContinue():
+            return True
+
+        no_branch = self.getBranchNo()
+
+        if no_branch is not None and no_branch.mayContinue():
+            return True
+
+        return False
