@@ -34,7 +34,7 @@ from logging import debug
 
 
 class VariableTraceBase:
-    def __init__(self, variable, version):
+    def __init__(self, variable, version, previous):
         self.variable = variable
         self.version = version
 
@@ -52,8 +52,8 @@ class VariableTraceBase:
         # time action.
         self.escaped_at = None
 
-    def isNode(self):
-        return False
+        # Previous trace this is replacing.
+        self.previous = previous
 
     def getVariable(self):
         return self.variable
@@ -90,28 +90,64 @@ class VariableTraceBase:
     def getDefiniteUsages(self):
         return self.usages
 
+    def getPrevious(self):
+        return self.previous
+
     def getReleases(self):
         return self.releases
 
-    def isAssignTrace(self):
+    @staticmethod
+    def isAssignTrace():
         return False
 
-    def isUninitTrace(self):
+    @staticmethod
+    def isUninitTrace():
         return False
 
-    def isUnknownTrace(self):
+    @staticmethod
+    def isInitTrace():
         return False
 
-    def isMergeTrace(self):
+    @staticmethod
+    def isUnknownTrace():
         return False
 
+    @staticmethod
+    def isMergeTrace():
+        return False
+
+    def mustHaveValue(self):
+        # TODO: Temporarily disable far reaching of assumptions, until value
+        # escaping can be trusted.
+        if self.variable.isModuleVariable() or \
+           self.variable.isSharedTechnically():
+            return False
+
+        return self.isInitTrace() or self.isAssignTrace()
+
+    def mustBeUninit(self):
+        if self.variable.isModuleVariable() or \
+           self.variable.isSharedTechnically():
+            return False
+
+        return self.isUninitTrace()
+
+    def mayBeUninit(self):
+        if self.variable.isModuleVariable() or \
+           self.variable.isSharedTechnically():
+            return True
+
+        return self.isUninitTrace() or self.isUnknownTrace()
+
+
 
 class VariableUninitTrace(VariableTraceBase):
-    def __init__(self, variable, version):
+    def __init__(self, variable, version, previous):
         VariableTraceBase.__init__(
             self,
             variable = variable,
-            version  = version
+            version  = version,
+            previous = previous
         )
 
     def __repr__(self):
@@ -120,7 +156,8 @@ class VariableUninitTrace(VariableTraceBase):
             version  = self.version
         )
 
-    def isUninitTrace(self):
+    @staticmethod
+    def isUninitTrace():
         return True
 
     def dump(self):
@@ -137,13 +174,60 @@ class VariableUninitTrace(VariableTraceBase):
 
             debug("  Used at %s", usage)
 
+        for merge in self.merges:
+            debug("   Merged to %s", merge)
 
-class VariableUnknownTrace(VariableTraceBase):
+        for release in self.releases:
+            debug("   Release by %s", release)
+
+
+class VariableInitTrace(VariableTraceBase):
     def __init__(self, variable, version):
         VariableTraceBase.__init__(
             self,
             variable = variable,
-            version  = version
+            version  = version,
+            previous = None
+        )
+
+    def __repr__(self):
+        return "<VariableInitTrace {variable} {version}>".format(
+            variable = self.variable,
+            version  = self.version
+        )
+
+    def dump(self):
+        debug(
+            "Trace of %s %d:",
+            self.variable,
+            self.version
+        )
+        debug("  Starts initialized")
+
+        for count, usage in enumerate(self.usages):
+            if count == self.escaped_at:
+                debug("  Escaped value")
+
+            debug("  Used at %s", usage)
+
+        for merge in self.merges:
+            debug("   Merged to %s", merge)
+
+        for release in self.releases:
+            debug("   Release by %s", release)
+
+    @staticmethod
+    def isInitTrace():
+        return True
+
+
+class VariableUnknownTrace(VariableTraceBase):
+    def __init__(self, variable, version, previous):
+        VariableTraceBase.__init__(
+            self,
+            variable = variable,
+            version  = version,
+            previous = previous
         )
 
     def __repr__(self):
@@ -166,16 +250,24 @@ class VariableUnknownTrace(VariableTraceBase):
 
             debug("  Used at %s", usage)
 
-    def isUnknownTrace(self):
+        for merge in self.merges:
+            debug("   Merged to %s", merge)
+
+        for release in self.releases:
+            debug("   Release by %s", release)
+
+    @staticmethod
+    def isUnknownTrace():
         return True
 
 
 class VariableAssignTrace(VariableTraceBase):
-    def __init__(self, assign_node, variable, version):
+    def __init__(self, assign_node, variable, version, previous):
         VariableTraceBase.__init__(
             self,
             variable = variable,
-            version  = version
+            version  = version,
+            previous = previous
         )
 
         self.assign_node = assign_node
@@ -185,14 +277,14 @@ class VariableAssignTrace(VariableTraceBase):
 <VariableAssignTrace {variable} {version} at {source_ref}>""".format(
             variable   = self.variable,
             version    = self.version,
-            source_ref = self.assign_node.getSourceReference()
+            source_ref = self.assign_node.getSourceReference().getAsString()
         )
 
     def dump(self):
         debug("Trace of %s %d:",
             self.variable,
-            self.version
-        )
+            self.version)
+        debug("  Starts assigned")
 
         for count, usage in enumerate(self.usages):
             if count == self.escaped_at:
@@ -200,7 +292,14 @@ class VariableAssignTrace(VariableTraceBase):
 
             debug("  Used at %s", usage)
 
-    def isAssignTrace(self):
+        for merge in self.merges:
+            debug("   Merged to %s", merge)
+
+        for release in self.releases:
+            debug("   Release by %s", release)
+
+    @staticmethod
+    def isAssignTrace():
         return True
 
     def getAssignNode(self):
@@ -219,16 +318,15 @@ class VariableMergeTrace(VariableTraceBase):
         VariableTraceBase.__init__(
             self,
             variable = variable,
-            version  = version
+            version  = version,
+            previous = (trace_yes, trace_no)
         )
 
-        self.trace_yes = trace_yes
-        self.trace_no = trace_no
-
         trace_yes.addMerge(self)
         trace_no.addMerge(self)
 
-    def isMergeTrace(self):
+    @staticmethod
+    def isMergeTrace():
         return True
 
     def dump(self):
@@ -239,6 +337,41 @@ class VariableMergeTrace(VariableTraceBase):
         )
         debug(
             "  Merge of %s <-> %s",
-            self.trace_yes,
-            self.trace_no
+            self.previous[0],
+            self.previous[1]
         )
+
+    def mustHaveValue(self):
+        # TODO: Temporarily disable far reaching of assumptions, until value
+        # escaping can be trusted.
+        if self.variable.isModuleVariable() or \
+           self.variable.isSharedTechnically():
+            return False
+
+        for previous in self.previous:
+            if not previous.isInitTrace() and not previous.isAssignTrace():
+                return False
+
+        return True
+
+    def mustBeUninit(self):
+        if self.variable.isModuleVariable() or \
+           self.variable.isSharedTechnically():
+            return False
+
+        for previous in self.previous:
+            if not previous.isUninitTrace():
+                return False
+
+        return True
+
+    def mayBeUninit(self):
+        if self.variable.isModuleVariable() or \
+           self.variable.isSharedTechnically():
+            return True
+
+        for previous in self.previous:
+            if not previous.isUninitTrace() and not previous.isUnknownTrace():
+                return False
+
+        return True
