@@ -169,7 +169,7 @@ def _buildClassNode3(provider, node, source_ref):
                 variable      = module_variable,
                 source_ref    = source_ref
             ),
-            source        = ExpressionConstantRef(
+            source       = ExpressionConstantRef(
                 constant      = provider.getParentModule().getFullName(),
                 source_ref    = source_ref,
                 user_provided = True
@@ -190,7 +190,7 @@ def _buildClassNode3(provider, node, source_ref):
                     variable      = doc_variable,
                     source_ref    = source_ref
                 ),
-                source        = ExpressionConstantRef(
+                source       = ExpressionConstantRef(
                     constant      = class_doc,
                     source_ref    = source_ref,
                     user_provided = True
@@ -310,12 +310,12 @@ def _buildClassNode3(provider, node, source_ref):
         source_ref = source_ref
     )
 
-    # The class body is basically a function that implicitely, at the end
+    # The class body is basically a function that implicitly, at the end
     # returns its locals and cannot have other return statements contained.
 
     class_creation_function.setBody(body)
 
-    # The class body is basically a function that implicitely, at the end
+    # The class body is basically a function that implicitly, at the end
     # returns its created class and cannot have other return statements
     # contained.
 
@@ -371,7 +371,7 @@ def _buildClassNode3(provider, node, source_ref):
                 source_ref = source_ref
             ),
             source       = makeDictCreationOrConstant(
-                keys      = [
+                keys       = [
                     ExpressionConstantRef(
                         constant      = keyword.arg,
                         source_ref    = source_ref,
@@ -380,7 +380,7 @@ def _buildClassNode3(provider, node, source_ref):
                     for keyword in
                     node.keywords
                 ],
-                values = [
+                values     = [
                     buildNode(provider, keyword.value, source_ref)
                     for keyword in
                     node.keywords
@@ -388,7 +388,7 @@ def _buildClassNode3(provider, node, source_ref):
                 lazy_order = False,
                 source_ref = source_ref
             ),
-            source_ref = source_ref
+            source_ref   = source_ref
         ),
         StatementAssignmentVariable(
             variable_ref = ExpressionTargetTempVariableRef(
@@ -396,8 +396,8 @@ def _buildClassNode3(provider, node, source_ref):
                 source_ref = source_ref
             ),
             source       = ExpressionSelectMetaclass(
-                metaclass = ExpressionConditional(
-                    condition = ExpressionComparison(
+                metaclass  = ExpressionConditional(
+                    condition      = ExpressionComparison(
                         comparator = "In",
                         left       = ExpressionConstantRef(
                             constant      = "metaclass",
@@ -433,7 +433,7 @@ def _buildClassNode3(provider, node, source_ref):
                         ),
                         yes_expression = ExpressionBuiltinType1(
                             value      = ExpressionSubscriptLookup(
-                                expression = ExpressionTempVariableRef(
+                                subscribed = ExpressionTempVariableRef(
                                     variable   = tmp_bases,
                                     source_ref = source_ref
                                 ),
@@ -450,13 +450,13 @@ def _buildClassNode3(provider, node, source_ref):
                     ),
                     source_ref     = source_ref
                 ),
-                bases     = ExpressionTempVariableRef(
+                bases      = ExpressionTempVariableRef(
                     variable   = tmp_bases,
                     source_ref = source_ref
                 ),
                 source_ref = source_ref
             ),
-            source_ref = source_ref_orig
+            source_ref   = source_ref_orig
         ),
         StatementConditional(
             condition  = ExpressionComparison(
@@ -475,11 +475,11 @@ def _buildClassNode3(provider, node, source_ref):
             no_branch  = None,
             yes_branch = makeStatementsSequenceFromStatement(
                 statement = StatementDictOperationRemove(
-                    dicte = ExpressionTempVariableRef(
+                    dicte      = ExpressionTempVariableRef(
                         variable   = tmp_class_decl_dict,
                         source_ref = source_ref
                     ),
-                    key   = ExpressionConstantRef(
+                    key        = ExpressionConstantRef(
                         constant      = "metaclass",
                         source_ref    = source_ref,
                         user_provided = True
@@ -495,7 +495,7 @@ def _buildClassNode3(provider, node, source_ref):
                 source_ref = source_ref
             ),
             source       = ExpressionConditional(
-                condition = ExpressionBuiltinHasattr(
+                condition      = ExpressionBuiltinHasattr(
                     object     = ExpressionTempVariableRef(
                         variable   = tmp_metaclass,
                         source_ref = source_ref
@@ -507,14 +507,14 @@ def _buildClassNode3(provider, node, source_ref):
                     ),
                     source_ref = source_ref
                 ),
-                no_expression = ExpressionConstantRef(
+                no_expression  = ExpressionConstantRef(
                     constant      = {},
                     source_ref    = source_ref,
                     user_provided = True
                 ),
                 yes_expression = ExpressionCall(
                     called     = ExpressionAttributeLookup(
-                        expression     = ExpressionTempVariableRef(
+                        source         = ExpressionTempVariableRef(
                             variable   = tmp_metaclass,
                             source_ref = source_ref
                         ),
@@ -541,17 +541,17 @@ def _buildClassNode3(provider, node, source_ref):
                     ),
                     source_ref = source_ref
                 ),
-                source_ref = source_ref
+                source_ref     = source_ref
             ),
-            source_ref = source_ref
+            source_ref   = source_ref
         ),
         StatementAssignmentVariable(
             variable_ref = ExpressionTargetVariableRef(
                 variable_name = node.name,
                 source_ref    = source_ref
             ),
-            source     = decorated_body,
-            source_ref = source_ref
+            source       = decorated_body,
+            source_ref   = source_ref
         ),
     )
 
@@ -569,32 +569,32 @@ def _buildClassNode3(provider, node, source_ref):
                 variable   = tmp_bases,
                 source_ref = source_ref
             ),
-            tolerant   = True,
-            source_ref = source_ref
+            tolerant     = True,
+            source_ref   = source_ref
         ),
         StatementDelVariable(
             variable_ref = ExpressionTargetTempVariableRef(
                 variable   = tmp_class_decl_dict,
                 source_ref = source_ref
             ),
-            tolerant   = True,
-            source_ref = source_ref
+            tolerant     = True,
+            source_ref   = source_ref
         ),
         StatementDelVariable(
             variable_ref = ExpressionTargetTempVariableRef(
                 variable   = tmp_metaclass,
                 source_ref = source_ref
             ),
-            tolerant   = True,
-            source_ref = source_ref
+            tolerant     = True,
+            source_ref   = source_ref
         ),
         StatementDelVariable(
             variable_ref = ExpressionTargetTempVariableRef(
                 variable   = tmp_prepared,
                 source_ref = source_ref
             ),
-            tolerant   = True,
-            source_ref = source_ref
+            tolerant     = True,
+            source_ref   = source_ref
         )
     )
 
@@ -631,7 +631,7 @@ def _buildClassNode2(provider, node, source_ref):
         # The frame guard has nothing to tell its line number to.
         body.source_ref = source_ref.atInternal()
 
-    # The class body is basically a function that implicitely, at the end
+    # The class body is basically a function that implicitly, at the end
     # returns its locals and cannot have other return statements contained, and
     # starts out with a variables "__module__" and potentially "__doc__" set.
     statements = [
@@ -640,7 +640,7 @@ def _buildClassNode2(provider, node, source_ref):
                 variable_name = "__module__",
                 source_ref    = source_ref
             ),
-            source        = ExpressionConstantRef(
+            source       = ExpressionConstantRef(
                 constant      = provider.getParentModule().getFullName(),
                 source_ref    = source_ref,
                 user_provided = True
@@ -656,7 +656,7 @@ def _buildClassNode2(provider, node, source_ref):
                     variable_name = "__doc__",
                     source_ref    = source_ref
                 ),
-                source        = ExpressionConstantRef(
+                source       = ExpressionConstantRef(
                     constant      = class_doc,
                     source_ref    = source_ref,
                     user_provided = True
@@ -681,14 +681,14 @@ def _buildClassNode2(provider, node, source_ref):
         source_ref = source_ref
     )
 
-    # The class body is basically a function that implicitely, at the end
+    # The class body is basically a function that implicitly, at the end
     # returns its locals and cannot have other return statements contained.
 
-    function_body.setBody( body )
+    function_body.setBody(body)
 
-    temp_scope = provider.allocateTempScope( "class_creation" )
+    temp_scope = provider.allocateTempScope("class_creation")
 
-    tmp_bases = provider.allocateTempVariable( temp_scope, "bases" )
+    tmp_bases = provider.allocateTempVariable(temp_scope, "bases")
     tmp_class_dict = provider.allocateTempVariable(temp_scope, "class_dict")
     tmp_metaclass = provider.allocateTempVariable(temp_scope, "metaclass")
     tmp_class = provider.allocateTempVariable(temp_scope, "class")
@@ -714,7 +714,7 @@ def _buildClassNode2(provider, node, source_ref):
                 source_ref = source_ref
             ),
             source       =   ExpressionFunctionCall(
-                function = ExpressionFunctionCreation(
+                function   = ExpressionFunctionCreation(
                     function_ref = ExpressionFunctionRef(
                         function_body = function_body,
                         source_ref    = source_ref
@@ -735,7 +735,7 @@ def _buildClassNode2(provider, node, source_ref):
                 source_ref = source_ref
             ),
             source       = ExpressionConditional(
-                condition =  ExpressionComparison(
+                condition      =  ExpressionComparison(
                     comparator = "In",
                     left       = ExpressionConstantRef(
                         constant      = "__metaclass__",
@@ -749,40 +749,40 @@ def _buildClassNode2(provider, node, source_ref):
                     source_ref = source_ref
                 ),
                 yes_expression = ExpressionDictOperationGet(
-                    dicte = ExpressionTempVariableRef(
+                    dicte      = ExpressionTempVariableRef(
                         variable   = tmp_class_dict,
                         source_ref = source_ref
                     ),
-                    key   = ExpressionConstantRef(
+                    key        = ExpressionConstantRef(
                         constant      = "__metaclass__",
                         source_ref    = source_ref,
                         user_provided = True
                     ),
                     source_ref = source_ref
                 ),
-                no_expression = ExpressionSelectMetaclass(
-                    metaclass = None,
-                    bases     = ExpressionTempVariableRef(
+                no_expression  = ExpressionSelectMetaclass(
+                    metaclass  = None,
+                    bases      = ExpressionTempVariableRef(
                         variable   = tmp_bases,
                         source_ref = source_ref
                     ),
                     source_ref = source_ref
                 ),
-                source_ref = source_ref
+                source_ref     = source_ref
             ),
-            source_ref = source_ref
+            source_ref   = source_ref
         ),
         StatementAssignmentVariable(
             variable_ref = ExpressionTargetTempVariableRef(
                 variable   = tmp_class,
                 source_ref = source_ref
             ),
-            source     = ExpressionCallNoKeywords(
-                called         = ExpressionTempVariableRef(
+            source       = ExpressionCallNoKeywords(
+                called     = ExpressionTempVariableRef(
                     variable   = tmp_metaclass,
                     source_ref = source_ref
                 ),
-                args           = ExpressionMakeTuple(
+                args       = ExpressionMakeTuple(
                     elements   = (
                         ExpressionConstantRef(
                             constant      = node.name,
@@ -802,13 +802,13 @@ def _buildClassNode2(provider, node, source_ref):
                 ),
                 source_ref = source_ref
             ),
-            source_ref = source_ref
+            source_ref   = source_ref
         ),
     ]
 
     for decorator in buildNodeList(
             provider,
-            reversed( node.decorator_list ),
+            reversed(node.decorator_list),
             source_ref
         ):
         statements.append(
@@ -820,7 +820,7 @@ def _buildClassNode2(provider, node, source_ref):
                 source       = ExpressionCallNoKeywords(
                     called     = decorator,
                     args       = ExpressionMakeTuple(
-                        elements  = (
+                        elements   = (
                             ExpressionTempVariableRef(
                                 variable   = tmp_class,
                                 source_ref = source_ref
@@ -840,11 +840,11 @@ def _buildClassNode2(provider, node, source_ref):
                 variable_name = node.name,
                 source_ref    = source_ref
             ),
-            source     = ExpressionTempVariableRef(
+            source       = ExpressionTempVariableRef(
                 variable   = tmp_class,
                 source_ref = source_ref
             ),
-            source_ref = source_ref
+            source_ref   = source_ref
         )
     )
 
@@ -854,32 +854,32 @@ def _buildClassNode2(provider, node, source_ref):
                 variable   = tmp_class,
                 source_ref = source_ref
             ),
-            tolerant   = True,
-            source_ref = source_ref
+            tolerant     = True,
+            source_ref   = source_ref
         ),
         StatementDelVariable(
             variable_ref = ExpressionTargetTempVariableRef(
                 variable   = tmp_bases,
                 source_ref = source_ref
             ),
-            tolerant   = True,
-            source_ref = source_ref
+            tolerant     = True,
+            source_ref   = source_ref
         ),
         StatementDelVariable(
             variable_ref = ExpressionTargetTempVariableRef(
                 variable   = tmp_class_dict,
                 source_ref = source_ref
             ),
-            tolerant   = True,
-            source_ref = source_ref
+            tolerant     = True,
+            source_ref   = source_ref
         ),
         StatementDelVariable(
             variable_ref = ExpressionTargetTempVariableRef(
                 variable   = tmp_metaclass,
                 source_ref = source_ref
             ),
-            tolerant   = True,
-            source_ref = source_ref
+            tolerant     = True,
+            source_ref   = source_ref
         )
     )
 
@@ -891,7 +891,7 @@ def _buildClassNode2(provider, node, source_ref):
 
 
 def buildClassNode(provider, node, source_ref):
-    assert getKind( node ) == "ClassDef"
+    assert getKind(node) == "ClassDef"
 
     # Python2 and Python3 are similar, but fundamentally different, so handle
     # them in dedicated code.
