@@ -51,15 +51,18 @@ def buildPrintNode(provider, node, source_ref):
 
     def wrapValue(value):
         if value.isExpressionConstantRef():
-            return value.getStrValue()
-        else:
-            return ExpressionBuiltinStr(
-                value      = value,
-                source_ref = value.getSourceReference()
-            )
+            str_value = value.getStrValue()
+
+            if str_value is not None:
+                return str_value
+
+        return ExpressionBuiltinStr(
+            value      = value,
+            source_ref = value.getSourceReference()
+        )
 
     if node.dest is not None:
-        temp_scope = provider.allocateTempScope( "print" )
+        temp_scope = provider.allocateTempScope("print")
 
         tmp_target_variable = provider.allocateTempVariable(
             temp_scope = temp_scope,
@@ -68,7 +71,7 @@ def buildPrintNode(provider, node, source_ref):
 
         target_default_statement = StatementAssignmentVariable(
             variable_ref = ExpressionTargetTempVariableRef(
-                variable   = tmp_target_variable.makeReference(provider),
+                variable   = tmp_target_variable,
                 source_ref = source_ref
             ),
             source       = ExpressionImportModuleHard(
@@ -82,7 +85,7 @@ def buildPrintNode(provider, node, source_ref):
         statements = [
             StatementAssignmentVariable(
                 variable_ref = ExpressionTargetTempVariableRef(
-                    variable   = tmp_target_variable.makeReference(provider),
+                    variable   = tmp_target_variable,
                     source_ref = source_ref
                 ),
                 source       = buildNode(
@@ -95,9 +98,7 @@ def buildPrintNode(provider, node, source_ref):
             StatementConditional(
                 condition  = ExpressionComparisonIs(
                     left       = ExpressionTempVariableRef(
-                        variable   = tmp_target_variable.makeReference(
-                            provider
-                        ),
+                        variable   = tmp_target_variable,
                         source_ref = source_ref
                     ),
                     right      = ExpressionConstantRef(
@@ -119,6 +120,7 @@ def buildPrintNode(provider, node, source_ref):
         nodes      = node.values,
         source_ref = source_ref
     )
+
     values = [
         wrapValue(value)
         for value in
@@ -129,9 +131,7 @@ def buildPrintNode(provider, node, source_ref):
         print_statements = [
             StatementPrintValue(
                 dest       = ExpressionTempVariableRef(
-                    variable   = tmp_target_variable.makeReference(
-                        provider
-                    ),
+                    variable   = tmp_target_variable,
                     source_ref = source_ref
                 ),
                 value      = value,
@@ -144,9 +144,7 @@ def buildPrintNode(provider, node, source_ref):
             print_statements.append(
                 StatementPrintNewline(
                     dest       = ExpressionTempVariableRef(
-                        variable   = tmp_target_variable.makeReference(
-                            provider
-                        ),
+                        variable   = tmp_target_variable,
                         source_ref = source_ref
                     ),
                     source_ref = source_ref
@@ -158,9 +156,7 @@ def buildPrintNode(provider, node, source_ref):
                 tried      = print_statements,
                 final      = StatementDelVariable(
                     variable_ref = ExpressionTargetTempVariableRef(
-                        variable   = tmp_target_variable.makeReference(
-                            provider
-                        ),
+                        variable   = tmp_target_variable,
                         source_ref = source_ref
                     ),
                     tolerant     = False,
