@@ -15,15 +15,21 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
+""" Reformulation of yield and yield from expressions.
 
-from nuitka.nodes.YieldNodes import ExpressionYield, ExpressionYieldFrom
-from nuitka.nodes.ConstantRefNodes import ExpressionConstantRef
+Consult the developer manual for information. TODO: Add ability to sync
+source code comments with developer manual sections.
+
+"""
+
+from nuitka import SyntaxErrors, Utils
 from nuitka.nodes.BuiltinIteratorNodes import ExpressionBuiltinIter1
-
-from nuitka import Utils, SyntaxErrors
+from nuitka.nodes.ConstantRefNodes import ExpressionConstantRef
+from nuitka.nodes.YieldNodes import ExpressionYield, ExpressionYieldFrom
 
 from .Helpers import buildNode
 
+
 def _markAsGenerator(provider, node, source_ref):
     if provider.isPythonModule():
         SyntaxErrors.raiseSyntaxError(
@@ -36,11 +42,11 @@ def _markAsGenerator(provider, node, source_ref):
 
 
 def buildYieldNode(provider, node, source_ref):
-    _markAsGenerator( provider, node, source_ref )
+    _markAsGenerator(provider, node, source_ref)
 
     if node.value is not None:
         return ExpressionYield(
-            expression = buildNode( provider, node.value, source_ref ),
+            expression = buildNode(provider, node.value, source_ref),
             source_ref = source_ref
         )
     else:
@@ -53,13 +59,14 @@ def buildYieldNode(provider, node, source_ref):
             source_ref = source_ref
         )
 
+
 def buildYieldFromNode(provider, node, source_ref):
     assert Utils.python_version >= 330
 
-    _markAsGenerator( provider, node, source_ref )
+    _markAsGenerator(provider, node, source_ref)
 
     iter_arg = ExpressionBuiltinIter1(
-        value      = buildNode( provider, node.value, source_ref ),
+        value      = buildNode(provider, node.value, source_ref),
         source_ref = source_ref
     )
 
