@@ -24,7 +24,7 @@ Only after this is executed, variable reference nodes can be considered
 complete.
 """
 
-from nuitka import SyntaxErrors
+from nuitka import PythonVersions, SyntaxErrors, Variables
 from nuitka.nodes.NodeMakingHelpers import makeConstantReplacementNode
 from nuitka.nodes.ReturnNodes import StatementGeneratorReturn
 from nuitka.Options import isFullCompat
@@ -54,7 +54,8 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
         until phase 2.
     """
 
-    def _handleNonLocal(self, node):
+    @staticmethod
+    def _handleNonLocal(node):
         # Take closure variables for non-local declarations.
 
         for non_local_names, source_ref in node.getNonlocalDeclarations():
@@ -63,9 +64,9 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
                     variable_name = non_local_name
                 )
 
-                node.registerProvidedVariable( variable )
+                node.registerProvidedVariable(variable)
 
-                if variable.isModuleVariableReference():
+                if variable.isModuleVariable():
                     SyntaxErrors.raiseSyntaxError(
                         "no binding for nonlocal '%s' found" % (
                             non_local_name
@@ -80,6 +81,38 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
                                        python_version >= 340
                     )
 
+    @staticmethod
+    def _handleQualnameSetup(node):
+        if node.qualname_setup is not None:
+            if node.isClassDictCreation():
+                class_assign, qualname_assign = node.qualname_setup
+                class_variable = class_assign.getTargetVariableRef().getVariable()
+
+                if class_variable.isModuleVariable():
+                    qualname_node = qualname_assign.getAssignSource()
+
+                    qualname_node.replaceWith(
+                        makeConstantReplacementNode(
+                            constant = class_variable.getName(),
+                            node     = qualname_node
+                        )
+                    )
+
+                    node.qualname_provider = node.getParentModule()
+            else:
+                function_variable_ref = node.qualname_setup
+                function_variable = function_variable_ref.getVariable()
+
+                if function_variable.isModuleVariable():
+                    node.qualname_provider = node.getParentModule()
+
+            # TODO: Actually for nested global classes, this approach
+            # may not work, as their qualnames will be wrong. In that
+            # case a dedicated node for qualname references might be
+            # needed.
+
+            node.qualname_setup = None
+
     def onEnterNode(self, node):
         # Mighty complex code with lots of branches and statements, but it
         # couldn't be less without making it more difficult.
@@ -107,11 +140,25 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
                 provider = node.getParentVariableProvider()
 
                 if provider.isEarlyClosure():
-                    node.setVariable(
-                        provider.getVariableForReference(
-                            variable_name = node.getVariableName()
-                        )
+                    variable = provider.getVariableForReference(
+                        variable_name = node.getVariableName()
                     )
+
+                    # Python3.4 version respects closure variables taken can be
+                    # overridden by writes to locals. It should be done for
+                    # globals too, on all versions, but for Python2 the locals
+                    # dictionary is avoided unless "exec" appears, so it's not
+                    # done.
+                    if variable.getOwner() is not provider:
+                        if python_version >= 340 or \
+                           (python_version >= 300 and \
+                            variable.isModuleVariable()):
+                            variable = Variables.MaybeLocalVariable(
+                                owner          = provider,
+                                maybe_variable = variable
+                            )
+
+                    node.setVariable(variable)
         elif node.isExpressionTempVariableRef():
             if node.getVariable().getOwner() != node.getParentVariableProvider():
                 node.setVariable(
@@ -119,9 +166,6 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
                         node.getVariable()
                     )
                 )
-
-                assert node.getVariable().isClosureReference(), \
-                  node.getVariable()
         elif node.isExpressionFunctionBody():
             if python_version >= 300:
                 self._handleNonLocal(node)
@@ -131,33 +175,8 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
 
             # Python3.4 allows for class declarations to be made global, even
             # after they were declared, so we need to fix this up.
-            if python_version >= 340 and node.isClassDictCreation():
-                class_assign, qualname_assign = node.qualname_setup
-                class_variable = class_assign.getTargetVariableRef().getVariable()
-
-                if class_variable.isModuleVariable() and \
-                   class_variable.isFromGlobalStatement():
-                    qualname_node = qualname_assign.getAssignSource()
-
-                    qualname_node.replaceWith(
-                        makeConstantReplacementNode(
-                            constant = class_variable.getName(),
-                            node     = qualname_node
-                        )
-                    )
-
-                    node.qualname_provider = node.getParentModule()
-
-                    # TODO: Actually for nested global classes, this approach
-                    # may not work, as their qualnames will be wrong. In that
-                    # case a dedicated node for qualname references might be
-                    # needed.
-
-                del node.qualname_setup
-
-
-
-
+            if python_version >= 340:
+                self._handleQualnameSetup(node)
         # Attribute access of names of class functions should be mangled, if
         # they start with "__", but do not end in "__" as well.
         elif node.isExpressionAttributeLookup() or \
@@ -165,8 +184,8 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
              node.isStatementDelAttribute():
             attribute_name = node.getAttributeName()
 
-            if attribute_name.startswith( "__" ) and \
-               not attribute_name.endswith( "__" ):
+            if attribute_name.startswith("__") and \
+               not attribute_name.endswith("__"):
                 seen_function = False
 
                 current = node
@@ -197,7 +216,8 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
             current = node
 
             while True:
-                if current.isPythonModule() or current.isExpressionFunctionBody():
+                if current.isPythonModule() or \
+                   current.isExpressionFunctionBody():
                     if node.isStatementContinueLoop():
                         message = "'continue' not properly in loop"
                         col_offset   = 16 if python_version >= 300 else None
@@ -215,9 +235,6 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
                             display_line = True
                             source_line  = None
 
-                    source_ref = node.getSourceReference()
-                    # source_ref.line += 1
-
                     SyntaxErrors.raiseSyntaxError(
                         message,
                         source_ref   = node.getSourceReference(),
@@ -245,13 +262,13 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
                    return_value.getConstant() is not None:
                     SyntaxErrors.raiseSyntaxError(
                         "'return' with argument inside generator",
-                        source_ref   = node.getSourceReference(),
+                        source_ref = node.getSourceReference(),
                     )
 
             node.replaceWith(
                 StatementGeneratorReturn(
-                    expression  = return_value,
-                    source_ref  = node.getSourceReference()
+                    expression = return_value,
+                    source_ref = node.getSourceReference()
                 )
             )
 
@@ -267,24 +284,27 @@ class VariableClosureLookupVisitorPhase2(VisitorNoopMixin):
         variable set now, the others, only in this phase.
     """
 
-    def _attachVariable(self, node, provider):
+    @staticmethod
+    def _attachVariable(node, provider):
         # print "Late reference", node.getVariableName(), "for", provider, "caused at", node, "of", node.getParent()
 
+        variable_name = node.getVariableName()
+
+        was_taken = provider.hasTakenVariable(variable_name)
+
         variable = provider.getVariableForReference(
-            variable_name = node.getVariableName()
+            variable_name = variable_name
         )
 
         node.setVariable(
             variable
         )
 
-        # Need to catch functions with "exec" not allowed.
+        # Need to catch functions with "exec" and closure variables not allowed.
         if python_version < 300 and \
+           not was_taken and \
            provider.isExpressionFunctionBody() and \
-           variable.isReference() and \
-             (not variable.isModuleVariableReference() or \
-              not variable.isFromGlobalStatement() ):
-
+           variable.getOwner() is not provider:
             parent_provider = provider.getParentVariableProvider()
 
             while parent_provider.isExpressionFunctionBody() and \
@@ -294,9 +314,9 @@ class VariableClosureLookupVisitorPhase2(VisitorNoopMixin):
             if parent_provider.isExpressionFunctionBody() and \
                parent_provider.isUnqualifiedExec():
                 SyntaxErrors.raiseSyntaxError(
-                    reason       = """\
-unqualified exec is not allowed in function '%s' it \
-contains a nested function with free variables""" % parent_provider.getName(),
+                    reason       = PythonVersions.\
+                                     getErrorMessageExecWithNestedFunction() % \
+                                     parent_provider.getName(),
                     source_ref   = parent_provider.getExecSourceRef(),
                     col_offset   = None,
                     display_file = True,
@@ -336,8 +356,6 @@ contains a nested function with free variables""" % parent_provider.getName(),
                         name       = "__class__"
                     )
 
-                    variable = variable.makeReference(parent_provider)
-
                     node.addClosureVariable(variable)
 
 
