@@ -21,17 +21,17 @@ from __future__ import print_function
 import inspect, types, sys
 
 def compiledFunction(a, b):
-   pass
+    pass
 
-assert inspect.isfunction( compiledFunction ) is True
-assert isinstance( compiledFunction, types.FunctionType )
-assert isinstance( compiledFunction, ( int, types.FunctionType ) )
+assert inspect.isfunction(compiledFunction) is True
+assert isinstance(compiledFunction, types.FunctionType)
+assert isinstance(compiledFunction, (int, types.FunctionType))
 
 print("Compiled spec:", inspect.getargspec(compiledFunction))
 print("Compiled args:", inspect.formatargspec(*inspect.getargspec(compiledFunction)))
 
 # Even this works.
-assert type( compiledFunction ) == types.FunctionType
+assert type(compiledFunction) == types.FunctionType
 
 class CompiledClass:
     def __init__(self):
@@ -46,10 +46,10 @@ assert isinstance(CompiledClass, types.FunctionType) is False
 assert inspect.ismethod(compiledFunction) is False
 assert inspect.ismethod(CompiledClass) is False
 
-assert inspect.ismethod(CompiledClass.compiledMethod) == ( sys.version_info < ( 3, ) )
+assert inspect.ismethod(CompiledClass.compiledMethod) == ( sys.version_info < (3, ) )
 assert inspect.ismethod(CompiledClass().compiledMethod) is True
 
-assert bool( type( CompiledClass.compiledMethod ) == types.MethodType ) == ( sys.version_info < ( 3, ) )
+assert bool(type(CompiledClass.compiledMethod) == types.MethodType) == ( sys.version_info < (3, ) )
 
 
 print("Compiled method:", inspect.getargspec(CompiledClass().compiledMethod))
@@ -57,14 +57,14 @@ print("Compiled class:", inspect.formatargspec(*inspect.getargspec(CompiledClass
 
 
 def compiledGenerator():
-   yield 1
+    yield 1
 
-assert inspect.isfunction( compiledGenerator ) is True
-assert inspect.isgeneratorfunction( compiledGenerator ) is True
+assert inspect.isfunction(compiledGenerator) is True
+assert inspect.isgeneratorfunction(compiledGenerator) is True
 
-assert isinstance( compiledGenerator(), types.GeneratorType ) is True
-assert type( compiledGenerator() ) == types.GeneratorType
-assert isinstance( compiledGenerator, types.GeneratorType ) is False
+assert isinstance(compiledGenerator(), types.GeneratorType) is True
+assert type(compiledGenerator()) == types.GeneratorType
+assert isinstance(compiledGenerator, types.GeneratorType) is False
 
 assert inspect.ismethod(compiledGenerator()) is False
 assert inspect.isfunction(compiledGenerator()) is False
@@ -75,18 +75,16 @@ assert inspect.isgenerator(compiledGenerator()) is True
 
 def someFunction(a):
     assert inspect.isframe(sys._getframe())
-    print("Running frame getframeinfo()", inspect.getframeinfo(sys._getframe()))
+    # print("Running frame getframeinfo()", inspect.getframeinfo(sys._getframe()))
 
     # TODO: The locals of the frame are not updated.
     # print("Running frame arg values", inspect.getargvalues(sys._getframe()))
 
 someFunction(2)
 
-import sys
-
 class C:
     print("Class frame", sys._getframe().f_code)
-    print("Class locals", str(sys._getframe().f_locals).replace( ", '__locals__': {...}", "" ).replace( "'__qualname__': 'C', ", "" ))
+    print("Class locals", str(sys._getframe().f_locals).replace(", '__locals__': {...}", "").replace("'__qualname__': 'C', ", ""))
     print("Class flags", sys._getframe().f_code.co_flags)
 
 def f():
