@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#     Copyright 2013, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -39,6 +39,11 @@ a = "partial print"
 try:
     print a, b
 except Exception, e:
-    print "then occured", repr(e)
+    print "then occurred", repr(e)
 
 print "No newline at the end",
+
+x = 1
+print """
+New line is no soft space, is it
+""", x
